@@ -36,7 +36,10 @@ function queuelogin_set_custom_on_default_template_add() {
             $mirow = $db->fetch_row($res);
             $jdata = $mirow[0];
             $data = json_decode($jdata);
-            $allowprofile = $data->{'fields'}->{'allowed_profiles'};
+            $allowprofile = array();
+            if(isset($data->fields->allowed_profiles) && is_array($data->fields->allowed_profiles)) {
+                $allowprofile = $data->{'fields'}->{'allowed_profiles'};
+            }
             $jscode = '$("#allowed_profiles").val(["'.implode('","',$allowprofile).'"]);'."\n";
             $jscode .= '$("#allowed_profiles").trigger("chosen:updated");'."\n";
             $jscode.="console.log('$allowprofile');\n";
